@@ -2,7 +2,6 @@ package Parse::CPAN::Meta;
 
 use strict;
 use Carp 'croak';
-use Module::Load::Conditional qw/can_load/;
 
 # UTF Support?
 sub HAVE_UTF8 () { $] >= 5.007003 }
@@ -18,7 +17,7 @@ BEGIN {
 	# Class structure
 	require 5.004;
 	require Exporter;
-	$Parse::CPAN::Meta::VERSION   = '1.4400';
+	$Parse::CPAN::Meta::VERSION   = '1.4403';
 	@Parse::CPAN::Meta::ISA       = qw{ Exporter      };
 	@Parse::CPAN::Meta::EXPORT_OK = qw{ Load LoadFile };
 }
@@ -55,13 +54,13 @@ sub load_json_string {
 sub yaml_backend {
   local $Module::Load::Conditional::CHECK_INC_HASH = 1;
   if (! defined $ENV{PERL_YAML_BACKEND} ) {
-    can_load( modules => {'CPAN::Meta::YAML' => 0.002}, verbose => 0 )
+    _can_load( 'CPAN::Meta::YAML', 0.002 )
       or croak "CPAN::Meta::YAML 0.002 is not available\n";
     return "CPAN::Meta::YAML";
   }
   else {
     my $backend = $ENV{PERL_YAML_BACKEND};
-    can_load( modules => {$backend => undef}, verbose => 0 )
+    _can_load( $backend )
       or croak "Could not load PERL_YAML_BACKEND '$backend'\n";
     $backend->can("Load")
       or croak "PERL_YAML_BACKEND '$backend' does not implement Load()\n";
@@ -72,12 +71,12 @@ sub yaml_backend {
 sub json_backend {
   local $Module::Load::Conditional::CHECK_INC_HASH = 1;
   if (! $ENV{PERL_JSON_BACKEND} or $ENV{PERL_JSON_BACKEND} eq 'JSON::PP') {
-    can_load( modules => {'JSON::PP' => 2.27103}, verbose => 0 )
+    _can_load( 'JSON::PP' => 2.27103 )
       or croak "JSON::PP 2.27103 is not available\n";
     return 'JSON::PP';
   }
   else {
-    can_load( modules => {'JSON' => 2.5}, verbose => 0 )
+    _can_load( 'JSON' => 2.5 )
       or croak  "JSON 2.5 is required for " .
                 "\$ENV{PERL_JSON_BACKEND} = '$ENV{PERL_JSON_BACKEND}'\n";
     return "JSON";
@@ -90,6 +89,21 @@ sub _slurp {
   return do { local $/; <$fh> };
 }
   
+sub _can_load {
+  my ($module, $version) = @_;
+  (my $file = $module) =~ s{::}{/}g;
+  $file .= ".pm";
+  return 1 if $INC{$file};
+  return 0 if exists $INC{$file}; # prior load failed
+  eval { require $file; 1 }
+    or return 0;
+  if ( defined $version ) {
+    eval { $module->VERSION($version); 1 }
+      or return 0;
+  }
+  return 1;
+}
+
 # Kept for backwards compatibility only
 # Create an object from a file
 sub LoadFile ($) {
